@@ -1,6 +1,6 @@
 $ENV{LIBEV_FLAGS} = 1;
 eval 'use EV';
-if ($@) {
+if ( $@ || EV::backend() != 1 ) {
   $| = 1;
   print qq(1..0 # Skip EV was not built with a select backend\n);
   CORE::exit(0);
